==> react_image_annotate_ns_workflow-6.0.6.tgz: package/Components/AnnotationInput.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
/** @format */

import React from "react";
import TaskFormLabel from "../OCR/TaskFormLabel";
// import { handleTooltipMessage } from '../../utils';
var AnnotationInput = function AnnotationInput(_ref) {
  var ref = _ref.ref,
    isTooltip = _ref.isTooltip,
    isAstrick = _ref.isAstrick,
    readOnly = _ref.readOnly,
    labelClass = _ref.labelClass,
    style = _ref.style,
    title = _ref.title,
    isRequired = _ref.isRequired,
    onChange = _ref.onChange,
    _ref$validation = _ref.validation,
    validation = _ref$validation === void 0 ? false : _ref$validation,
    placeholder = _ref.placeholder,
    value = _ref.value,
    errorMessage = _ref.errorMessage,
    name = _ref.name,
    type = _ref.type,
    onKeyDown = _ref.onKeyDown,
    isDisabled = _ref.isDisabled,
    onblur = _ref.onblur,
    className = _ref.className,
    subTextAboveInput = _ref.subTextAboveInput,
    onFocus = _ref.onFocus,
    count = _ref.count,
    invalid = _ref.invalid,
    invalid_show = _ref.invalid_show,
    handleInvalid = _ref.handleInvalid;
  function Count(str) {
    var upper = 0;
    var lower = 0;
    var number = 0;
    for (var i = 0; i < str.length; i++) {
      if (str[i] >= "A" && str[i] <= "Z") upper++;else if (str[i] >= "a" && str[i] <= "z") lower++;else if (str[i] >= "0" && str[i] <= "9") number++;
    }
    return upper + lower + number;
  }
  var handleTooltipMessage = function handleTooltipMessage() {};
  var showCharacterCount = function showCharacterCount(totalCount) {
    return /*#__PURE__*/React.createElement("span", {
      style: {
        fontSize: "0.7rem"
      },
      className: "text-green-600 flex justify-start absolute  bottom-2"
    }, String(totalCount).length);
  };
  return /*#__PURE__*/React.createElement("div", {
    className: "common_inputBox flex flex-col ".concat(className ? className : "")
  }, title && /*#__PURE__*/React.createElement(TaskFormLabel, {
    display_label: title,
    isAstrick: isAstrick,
    isRequired: isRequired,
    isTooltip: isTooltip,
    invalid: invalid,
    invalid_show: invalid_show,
    handleInvalid: handleInvalid
  }), subTextAboveInput && /*#__PURE__*/React.createElement("label", null, subTextAboveInput), /*#__PURE__*/React.createElement("textarea", {
    readOnly: readOnly,
    style: _objectSpread({}, style, {
      backgroundColor: "#edf2f7"
    }),
    autoComplete: "off",
    className: "font-MontMedium text-sm ant-input",
    onFocus: onFocus,
    name: name,
    type: type,
    placeholder: placeholder,
    value: value,
    onChange: onChange,
    onKeyDown: onKeyDown ? onKeyDown : null,
    disabled: isDisabled,
    onBlur: onblur,
    min: 0,
    spellCheck: false,
    ref: ref,
    rows: 3
  }), validation && /*#__PURE__*/React.createElement("span", {
    className: "common_error"
  }, errorMessage), (value === null || value === void 0 ? void 0 : value.length) > 0 && count && showCharacterCount(value));
};
export default AnnotationInput;

==> react_image_annotate_ns_workflow-7.0.9.tgz: package/Components/AnnotationInput.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
/** @format */

import React from "react";
import TaskFormLabel from "../OCR/TaskFormLabel";
// import { handleTooltipMessage } from '../../utils';
var AnnotationInput = function AnnotationInput(_ref) {
  var ref = _ref.ref,
    isTooltip = _ref.isTooltip,
    isAstrick = _ref.isAstrick,
    readOnly = _ref.readOnly,
    labelClass = _ref.labelClass,
    style = _ref.style,
    title = _ref.title,
    isRequired = _ref.isRequired,
    onChange = _ref.onChange,
    _ref$validation = _ref.validation,
    validation = _ref$validation === void 0 ? false : _ref$validation,
    placeholder = _ref.placeholder,
    value = _ref.value,
    errorMessage = _ref.errorMessage,
    name = _ref.name,
    type = _ref.type,
    onKeyDown = _ref.onKeyDown,
    isDisabled = _ref.isDisabled,
    onblur = _ref.onblur,
    className = _ref.className,
    subTextAboveInput = _ref.subTextAboveInput,
    onFocus = _ref.onFocus,
    count = _ref.count,
    invalid = _ref.invalid,
    invalid_show = _ref.invalid_show,
    handleInvalid = _ref.handleInvalid,
    isTL = _ref.isTL;
  function Count(str) {
    var upper = 0;
    var lower = 0;
    var number = 0;
    for (var i = 0; i < str.length; i++) {
      if (str[i] >= "A" && str[i] <= "Z") upper++;else if (str[i] >= "a" && str[i] <= "z") lower++;else if (str[i] >= "0" && str[i] <= "9") number++;
    }
    return upper + lower + number;
  }
  var handleTooltipMessage = function handleTooltipMessage() {};
  var showCharacterCount = function showCharacterCount(totalCount) {
    return /*#__PURE__*/React.createElement("span", {
      style: {
        fontSize: "0.7rem"
      },
      className: "text-green-600 flex justify-start absolute  bottom-2"
    }, String(totalCount).length);
  };
  return /*#__PURE__*/React.createElement("div", {
    className: "common_inputBox flex flex-col ".concat(className ? className : "")
  }, title && /*#__PURE__*/React.createElement(TaskFormLabel, {
    display_label: title,
    isAstrick: isAstrick,
    isRequired: isRequired,
    isTooltip: isTooltip,
    invalid: invalid,
    invalid_show: invalid_show,
    isTL: isTL,
    handleInvalid: handleInvalid
  }), subTextAboveInput && /*#__PURE__*/React.createElement("label", null, subTextAboveInput), /*#__PURE__*/React.createElement("textarea", {
    readOnly: readOnly,
    style: _objectSpread({}, style, {
      backgroundColor: "#edf2f7"
    }),
    autoComplete: "off",
    className: "font-MontMedium text-sm ant-input",
    onFocus: onFocus,
    name: name,
    type: type,
    placeholder: placeholder,
    value: value,
    onChange: onChange,
    onKeyDown: onKeyDown ? onKeyDown : null,
    disabled: isDisabled,
    onBlur: onblur,
    min: 0,
    spellCheck: false,
    ref: ref,
    rows: 3
  }), validation && /*#__PURE__*/React.createElement("span", {
    className: "common_error"
  }, errorMessage), (value === null || value === void 0 ? void 0 : value.length) > 0 && count && showCharacterCount(value));
};
export default AnnotationInput;
